@@ -146,7 +146,7 @@ class Client:
                     to be added
         '''
         #Client ID, Patient ID, and MRN are immutable
-        if key == "CLIENT_ID" or key == "MRN" or key == "PATIENT_ID":
+        if key == "CLIENT_ID" or key == "MRN" or key == "PATIENT_ID" or key == "PATIENT_PARTITION":
             return ''
 
         if self.overwrite == False and patient_data_value is None:
@@ -193,7 +193,7 @@ class Client:
         # compare, the changes in the two records
         for k in patient_data:
             if k == "CLIENT_ID" or k == "MRN" or k == "PATIENT_ID" \
-            or k == "UPDATED_AT" or k == "CHECKSUM":
+            or k == "UPDATED_AT" or k == "CHECKSUM" or k == "PATIENT_PARTITION":
                 continue
 
             elif not self.__is_updateable(patient_data[k], patient_row.get(k)):
