@@ -7,7 +7,7 @@ from indxdatalaketools.GoogleClientWrappers import SecretManager
 from indxdatalaketools import Helpers
 import json
 
-DOCUMENT_CLASSIFIER_URL = 'https://document-classifier-gateway-27i5vb12.uc.gateway.dev/'
+DOCUMENT_CLASSIFIER_URL = 'https://documentclassifier.indx.acuityeyegroup.dev/'
 
 
 class DocClassifierClient:
@@ -42,6 +42,8 @@ class DocClassifierClient:
                                                "predict",
                                                headers=headers,
                                                body=data)
+        if response is None:
+            return None, None
         classified_modality = response['modality']
         classified_file_type = response['file_type']
 
